
php_ver=$(php -v | awk 'NR==1{print $2}')
if [ -z "$php_ver" ]; then cat >&2 << 'EOF'
xdebug package: skipped adding xdebug.ini because php is not installed.
To fix this error please uninstall xdebug, install php then install xdebug.
EOF
exit
fi

config="\
xdebug.remote_enable=on
xdebug.remote_handler=dbgp
xdebug.remote_host=localhost
xdebug.remote_port=9000
xdebug.var_display_max_data = 2048
xdebug.var_display_max_depth = 5
"

# try adding a configuration file
for p in ./etc/php/$php_ver ./etc/php/${php_ver%.*} ./etc/php; do
  if [ -d $p/conf.d ]; then
    f="$p/conf.d/99-xdebug.ini"
    if [ -e "$f" ]; then
      echo "$config" > "$f.new" &&
        echo "sample xdebug configuration file written: $f.new" >&2
    else
      echo "$config" > "$f" &&
        echo "please review xdebug configuration file: $f" >&2
    fi
    unset config
    break
  fi
done
# if a configuration file wasn't added above append xdebug settings to php.ini

# add xdebug.so extension and possibly its settings to php.ini
# unless xdebug is already installed
if ! grep -q '^zend_extension="xdebug.so"$' ./etc/php.ini; then
	echo "
; begin added by package xdebug -- do not delete this line
zend_extension="xdebug.so"
$config
; end added by package xdebug -- do not delete this line
" >> ./etc/php.ini
fi

cat << 'EOF'
  +----------------------------------------------------------------------+
  |                                                                      |
  |   INSTALLATION INSTRUCTIONS                                          |
  |   =========================                                          |
  |                                                                      |
  |   See https://xdebug.org/install.php#configure-php for instructions  |
  |   on how to enable Xdebug for PHP.                                   |
  |                                                                      |
  |   Documentation is available online as well:                         |
  |   - A list of all settings:  https://xdebug.org/docs-settings.php    |
  |   - A list of all functions: https://xdebug.org/docs-functions.php   |
  |   - Profiling instructions:  https://xdebug.org/docs-profiling2.php  |
  |   - Remote debugging:        https://xdebug.org/docs-debugger.php    |
  |                                                                      |
  |                                                                      |
  |   NOTE: Please disregard the message                                 |
  |       You should add "extension=xdebug.so" to php.ini                |
  |   that is emitted by the PECL installer. This does not work for      |
  |   Xdebug.                                                            |
  |                                                                      |
  +----------------------------------------------------------------------+
EOF
